<figure markdown>
![Logo](https://raw.githubusercontent.com/zehengl/toisan-lang/main/logo.jpg){ width="100" }
</figure>

# toisan-lang

A programming language based on Toisanese, aka Taishanese, a dialect of Cantonese
